pyphasefield.tests package — pyphasefield documentation

# pyphasefield.tests package

## Submodules

## pyphasefield.tests.test_Diffusion module

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson1D()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson1D_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson2D()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson2D_ADI()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson2D_ADI_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson2D_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson3D()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson3D_ADI()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson3D_ADI_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_CrankNicolson3D_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit1D()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit1D_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit2D()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit2D_ADI()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit2D_ADI_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit2D_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit3D()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit3D_ADI()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit3D_ADI_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_Implicit3D_GMRES()

pyphasefield.tests.test_Diffusion.test_diffusion_default1dexplicit()

pyphasefield.tests.test_Diffusion.test_diffusion_default2dexplicit()

pyphasefield.tests.test_Diffusion.test_diffusion_default3dexplicit()

## pyphasefield.tests.test_NComponent module

pyphasefield.tests.test_NComponent.test_ncomponent()

  Simple Test of N-Component model, minimum size to avoid seed overstepping bounds

pyphasefield.tests.test_NComponent.test_ncomponent_1d()

  Tests a 2d sim, but with one dimension of length 1, equivalent to a 1d simulation

pyphasefield.tests.test_NComponent.test_ncomponent_1d_actual()

  Tests a 1d sim

pyphasefield.tests.test_NComponent.test_ncomponent_very_small()

  Tests what happens when the seed exceeds the size of the sim region

## pyphasefield.tests.test_SaveLoad module

pyphasefield.tests.test_SaveLoad.teardown_module(module)

pyphasefield.tests.test_SaveLoad.test_1_saving()

pyphasefield.tests.test_SaveLoad.test_2_loading_step_number()

pyphasefield.tests.test_SaveLoad.test_3_loading_relative_path()

pyphasefield.tests.test_SaveLoad.test_4_loading_absolute_path()

## pyphasefield.tests.test_Warren1995 module

pyphasefield.tests.test_Warren1995.test_warren1995()

## Module contents